=========
Tutorials
=========

Tutorial 0
----------

In :doc:`tutorial-0`, you will discover how to create a basic app and have a simple :mod:`toga.interface.widgets.button.Button` widget to click.

.. figure:: screenshots/tutorial-0.png
    :align: center
    :width: 300

Tutorial 1
----------

In :doc:`tutorial-1`, you will discover how to capture basic user input using the :mod:`toga.interface.widgets.textinput.TextInput` widget 
and control layout.

.. figure:: screenshots/tutorial-1.png
    :align: center
    :width: 300

Tutorial 2
----------

In :doc:`tutorial-2`, you will discover how to use the :mod:`toga.interface.widgets.splitcontainer.SplitContainer` widget to display
some components, a toolbar and a table.

.. figure:: screenshots/tutorial-2.png
    :align: center
    :width: 300

Tutorial 3
----------

In :doc:`tutorial-3`, you will discover how to use the :mod:`toga.interface.widgets.webview.WebView` widget to display
a simple browser.

.. figure:: screenshots/tutorial-3.png
    :align: center
    :width: 300


Index
-----

.. toctree::
   :maxdepth: 2
   :glob:

   tutorial-0
   tutorial-1
   tutorial-2
   tutorial-3
